# **Fractal** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 这是一个数学中的分形模块,专门绘制分形图像
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.6-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/项目-分形-black.svg)]()

### 介绍
    分形理论(Fractal Theory)是当今十分风靡和活跃的新理论、新学科。分形的概念是美籍数学家本华·曼德博
    （法语：Benoit B. Mandelbrot）首先提出的。分形理论的数学基础是分形几何学，即由分形几何衍生出分形信息、
    分形设计、分形艺术等应用。具有自相似性的形态广泛存在于自然界中，如：连绵的山川、飘浮的云朵、岩石的断裂口、
    粒子的布朗运动、树冠、花菜、大脑皮层……Mandelbrot把这些部分与整体以某种方式相似的形体称为分形(fractal)。

#### 安装
    pip install jtyoui

***
[1]: https://blog.jtyoui.com